%**********************************************************
% Example 3: calc_para_eq.m                               *
% (calls the functions paraf.m and qparaf.m)              *
%                                                         *
% Calculation of paraequilibrium and quasi-               *
% paraconditions for an alloy with at least one           *
% interstitial component (e.g. N or C).                   *
% Demonstrates also the coding of an interactive program  *
%                                                         *
%                                                         *
%**********************************************************
global uc0 cmp depcmp intcmp;

% Initialize Thermo-Calc

tc_init_root;

% Prompt user for database, components and phases

dtbs='FEDEMO';
cmp={'FE' 'C' 'CR'};
phx={'BCC' 'FCC'};
dtbs=tc_prompts('Database',dtbs);
cmp=tc_promptsn('Components',cmp);
phx=tc_promptsn('Phases',phx);
tc_define_system(dtbs,cmp,{'*'},phx);
if (length(cmp) < 2 ) error('No enough components defined'); end;
if (length(phx)~=2) error('Must define 2 phases');  end;

% Check for errors and reset them

tc_check_error;

% Check which interstitial user selected.
% Legal entries are C and N
nx=length(cmp);
depcmp='';
intcmp='';
for ix=1:nx
	if strcmp(cmp{ix},'FE')  ;
		depcmp='FE'; 
	end;
	if strcmp(cmp{ix},'C')  ;
		intcmp='C'; 
	end;
	if strcmp(cmp{ix},'N')  ;
		intcmp='N'; 
	end;
end;
depcmp=tc_prompts('dependent component',depcmp);
ifcd=0;
for ix=1:nx
	if strcmp(cmp{ix},depcmp)  ;
		ifcd=1;
	end;
end;
if ifcd == 0  ;
	error('Component not found');
end;
intcmp=tc_prompts('interstitial component',intcmp);
ifci=0;
for ix=1:nx
	if strcmp(cmp{ix},intcmp)  ;
		ifci=1;
	end;
end;
if ifcd == 0  ;
	error('Component not found');
end;

% Prompt user for temperature and composition of the
% immobile element and start composition for interstitial
% element

temp=1100;
udep0=0.005; 
uint0=0.005;
temp=tc_promptr('Temperature',temp);

for ix=1:nx
	if ~strcmp(cmp{ix},intcmp)  ;
		if ~strcmp(cmp{ix},depcmp)  ;
			s=sprintf('U-fraction of %s',cmp{ix});
			indepv(ix)=udep0;
			indepv(ix)=tc_promptr(s,indepv(ix));
		end
	end;
end;

for ix=1:nx
	if strcmp(cmp{ix},intcmp)  ;
		s=sprintf('start value for U-fraction of %s',cmp{ix});
		indepv(ix)=uint0;
		indepv(ix)=tc_promptr(s,indepv(ix));
		uc0=indepv(ix);
	end;
end;

% sets the conditions in Thermo-Calc

for ix=1:2
	ieq=1000+ix;
	tc_select_equilibrium(ieq);
	[ierr,mess]=tc_error;
	if  ierr ~= 0 
		tc_reset_error;
		tc_create_new_equilibrium(ieq);
	end
	tc_set_condition('T',temp);
	tc_set_condition('P',101325);


	substr=' ';
	for jx=1:nx
		if strcmp(cmp{jx},intcmp)  ;
			s=sprintf('N(%s)',cmp{jx});
			tc_set_condition(s,indepv(jx));
		else
			s1=substr;
			s2=sprintf('N(%s)+',cmp{jx});
			substr=strcat(s1,s2);
			if ~strcmp(cmp{jx},depcmp)  ;
				s=sprintf('N(%s)',cmp{jx});
				tc_set_condition(s,indepv(jx));
			end;
		end;
	end;
	ip=length(substr);
	substr=substr(1:ip-1);
	tc_set_condition(substr,1);
	tc_set_phase_status('*','SUSPENDED',0);
	if ix == 1
		tc_set_phase_status(phx{1},'ENTERED',1);
	else
		tc_set_phase_status(phx{2},'ENTERED',1);
	end
	tc_compute_equilibrium;
	tc_check_error;
end;

% nc(1)=1;	nc(2)=1;
nc=1;
s=sprintf('MU(%s)',intcmp);
uc0=tc_get_value(s);

for ix=1:2
	ieq=1000+ix;
	tc_select_equilibrium(ieq);
	s=sprintf('N(%s)',intcmp);
	tc_delete_condition(s);
end;


% Calculates the paraequilibrium

ncc=fminsearch('paraf',nc);

disp(' ');
s=sprintf(' Paraequilibrium between %s and %s ',phx{1},phx{2});
disp(s);
for ix=1:2
	ieq=1000+ix;
	tc_select_equilibrium(ieq);
	nx=length(cmp);
	jk=0;
	substr=' ';
	for jx=1:nx
		if ~strcmp(cmp{jx},depcmp);
			jk=jk+1;
			s2=sprintf('UF(%s,%s)   ',phx{ix},cmp{jx});
			ip2=length(s2);
			ip=(jk-1)*14+2;
			substr(ip:ip+ip2-1)=s2;
		end
	end
	for jx=1:nx
		if ~strcmp(cmp{jx},depcmp);
			jk=jk+1;
			s2=sprintf('MU(%s,%s)   ',phx{ix},cmp{jx});
			ip2=length(s2);
			ip=(jk-1)*14+2;
			substr(ip:ip+ip2-1)=s2;
		end
	end
	disp(substr);

	jk=0;
	substr=' ';
	for jx=1:nx
		if ~strcmp(cmp{jx},depcmp);
			jk=jk+1;
			s1=sprintf('N(%s)',cmp{jx});
			r=tc_get_value(s1);
			s2=sprintf('%0.8g',r);
			ip2=length(s2);
			ip=(jk-1)*14+2;
			substr(ip:ip+ip2-1)=s2;
		end
	end
	for jx=1:nx
		if ~strcmp(cmp{jx},depcmp);
			jk=jk+1;
			s1=sprintf('MU(%s)',cmp{jx});
			r=tc_get_value(s1);
			s2=sprintf('%0.8g',r);
			ip2=length(s2);
			ip=(jk-1)*14+2;
			substr(ip:ip+ip2-1)=s2;
		end
	end
	disp(substr);
	disp(' ');
	for jx=1:nx
		s1=sprintf('MU(%s)',cmp{jx});
		muall(ix,jx)=tc_get_value(s1);
	end
end

for jx=1:nx
	mux(jx)=(muall(1,jx)+muall(1,jx))/2;
end


for ix=1:2
	ieq=1000+ix;
	tc_select_equilibrium(ieq);
	tc_delete_condition('*');
	tc_set_condition('T',temp);
	tc_set_condition('P',101325);

	substr=' ';

	for jx=1:nx
		if ~strcmp(cmp{jx},intcmp);
			if ~strcmp(cmp{jx},depcmp);
				if ix == 1
					s=sprintf('N(%s)',cmp{jx});
					tc_set_condition(s,indepv(jx));
				else
					s=sprintf('MU(%s)',cmp{jx});
					tc_set_condition(s,mux(jx));
				end	
			end
		end	
	end
	for jx=1:nx
		if strcmp(cmp{jx},intcmp)  ;
			s=sprintf('MU(%s)',cmp{jx});
			tc_set_condition(s,mux(jx));
			muc0=mux(jx);
		else
			s1=substr;
			s2=sprintf('N(%s)+',cmp{jx});
			substr=strcat(s1,s2);
		end;
	end;
	ip=length(substr);
	substr=substr(1:ip-1);
	tc_set_condition(substr,1);

	tc_set_phase_status('*','SUSPENDED',0);
	if ix == 1
		tc_set_phase_status(phx{1},'ENTERED',1);
	else
		tc_set_phase_status(phx{2},'ENTERED',1);
	end
	tc_compute_equilibrium;
	tc_check_error;
end;

% Calculates the quasi-paraequilibrium
smui=1;
ncc=fminsearch('qparaf',smui);

disp(' ');
s=sprintf(' Quasi-paraequilibrium, %s growing into %s ',phx{1},phx{2});
disp(s);
for ix=1:2
	ieq=1000+ix;
	tc_select_equilibrium(ieq);
	nx=length(cmp);
	jk=0;
	substr=' ';
	for jx=1:nx
		if ~strcmp(cmp{jx},depcmp);
			jk=jk+1;
			s2=sprintf('UF(%s,%s)   ',phx{ix},cmp{jx});
			ip2=length(s2);
			ip=(jk-1)*14+2;
			substr(ip:ip+ip2-1)=s2;
		end
	end
	for jx=1:nx
		if ~strcmp(cmp{jx},depcmp);
			jk=jk+1;
			s2=sprintf('MU(%s,%s)   ',phx{ix},cmp{jx});
			ip2=length(s2);
			ip=(jk-1)*14+2;
			substr(ip:ip+ip2-1)=s2;
		end
	end
	disp(substr);

	jk=0;
	substr=' ';
	for jx=1:nx
		if ~strcmp(cmp{jx},depcmp);
			jk=jk+1;
			s1=sprintf('N(%s)',cmp{jx});
			r=tc_get_value(s1);
			s2=sprintf('%0.8g',r);
			ip2=length(s2);
			ip=(jk-1)*14+2;
			substr(ip:ip+ip2-1)=s2;
		end
	end
	for jx=1:nx
		if ~strcmp(cmp{jx},depcmp);
			jk=jk+1;
			s1=sprintf('MU(%s)',cmp{jx});
			r=tc_get_value(s1);
			s2=sprintf('%0.8g',r);
			ip2=length(s2);
			ip=(jk-1)*14+2;
			substr(ip:ip+ip2-1)=s2;
		end
	end
	disp(substr);
	disp(' ');
end
