%***********************************************************
% Example 1 (ex01.m)                                       *
%                                                          *
% Calculation of a single equilibrium in Fe-Cr-C           *
% at 1200 K                                                *
%***********************************************************
% Initiate the TC system
tc_init_root;
% Choose database
tc_open_database('FEDEMO');
% Check for errors
[a,b]=tc_error;
if a~=0
    s=sprintf(' ERROR %d',a);
    disp(s);
    disp(b);
    return;
end
% Select elements and retrieve data
sel='fe cr c';
tc_element_select(sel);
tc_get_data;
% Set conditions
tc_set_condition('t',1200);
tc_set_condition('p',101325);
tc_set_condition('n',1);
tc_set_condition('x(cr)',1e-2);
tc_set_condition('x(c)',1e-3);
% Compute equilibrium and check for errors
tc_compute_equilibrium;
[a,b]=tc_error;
if a~=0
    s=sprintf(' ERROR %d',a);
    disp(s);
    disp(b);
end
tc_reset_error;
% Get the chemical potentials for carbon and cromium in
% the system and display them.
muc=tc_get_value('mu(c)');
mucr=tc_get_value('mu(cr)');
s1=sprintf(' The chemical potential for C is %0.5g J/mol',muc);
disp(s1);
s2=sprintf(' The chemical potential for Cr is %0.5g J/mol',mucr); disp(s2);