%*****************************************************
% Example 2 (ex02.m)                                 *
%                                                    *
% Calculation of a molar Gibbs energy surface in an  *
% Al-Cu-Si alloy                                     * 
%*****************************************************
% Initiate the TC system
tc_init_root;
% Choose database
tc_open_database('ALDEMO');
% Check for errors and reset them
tc_check_error;
% Select elements and retrieve data
sel='al cu si';
tc_element_select(sel);
tc_get_data;
% Set conditions
tc_set_condition('t',800);
tc_set_condition('n',1);
tc_set_condition('p',101325);
% Create vectors with compositions of cu and si
k=40;
xcu=linspace(1e-4,0.05,k);
xsi=linspace(1e-4,0.05,k);
% Loop to calculate the molar Gibbs energy surface
for icu=1:k;
    tc_set_condition('x(cu)',xcu(icu));
    for isi=1:k;
        tc_set_condition('x(si)',xsi(isi));
        tc_compute_equilibrium;
        tc_check_error;
        Z(icu,isi,1)=tc_get_value('gm(hcp_a3)');
        Z(icu,isi,2)=tc_get_value('gm(liq)');
    end;
end;
% Plot a 3-D surface
figure(1)
surf(xcu,xsi,Z(:,:,1));
hold on;
surf(xcu,xsi,Z(:,:,2));

figure(2)
subplot(2,1,1)
surf(xcu,xsi,Z(:,:,1));
subplot(2,1,2)
surf(xcu,xsi,Z(:,:,2));
% Set axis text and enable rotation of plot
xlabel('mole-fraction copper');
ylabel('mole-fraction silicon');
zlabel('Molar Gibbs energy (J/mol)');
rotate3d on;