%**********************************************************
% Example 4 (ex04.m)                                      *
%                                                         *
% Calculation of the so-called T-zero line in Fe-C.       *
%                                                         *
%**********************************************************
% Initiate the TC subsystem
tc_init_root;
% Define the system and retrieve data
dtbs='FEDEMO';
sel={'fe c'};
phs={'bcc fcc'};
tc_define_system(dtbs,sel,{'*'},phs);
% Check for errors and reset them
tc_check_error;
% Set conditions
tc_set_condition('p',101325);
tc_set_condition('n',1);
% Define some limits
xmin=1e-3;
xmax=9e-3;
dx=1e-3;
Tmax0=1200;
Tmin0=1000;
s=sprintf(' x(C)  T0 [K]');
disp(s);
s=sprintf(' -------------');
disp(s);
% Loop over all mole-fractions of C
xc0=[];
T0=[];
for xc=xmin:dx:xmax;
Tmax=Tmax0;
Tmin=Tmin0;
T=(Tmax0+Tmin0)*0.5;
tc_set_condition('t',T);
tc_set_condition('x(c)',xc);
tc_set_phase_status('fcc','entered',1);
tc_set_phase_status('bcc','suspended',0);
tc_compute_equilibrium;
tc_check_error;
gm1=tc_get_value('gm(fcc)');
tc_set_phase_status('fcc','suspended',0);
tc_set_phase_status('bcc','entered',1);
tc_compute_equilibrium;
tc_check_error;
gm2=tc_get_value('gm(bcc)');
gm0=(gm1-gm2)/gm1;
feps=1e-10;
while (abs(gm0) > feps)
    if(gm0 < 0)
        Tmin=T;
        T=(T+Tmax)*0.5;
    end;
    if(gm0 > 0)
        Tmax=T;
        T=(T+Tmin)*0.5;
    end;
    tc_set_condition('t',T);
    tc_set_phase_status('fcc','entered',1);
    tc_set_phase_status('bcc','suspended',0);
    tc_compute_equilibrium;
    gm1=tc_get_value('gm(fcc)');
    tc_set_phase_status('fcc','suspended',0);
    tc_set_phase_status('bcc','entered',1);
    tc_compute_equilibrium;
    gm2=tc_get_value('gm(bcc)');
    gm0=(gm1-gm2)/gm1;
end;
s=sprintf(' %0.5g %0.5g',xc,T);
T0=[T0 T];
xc0=[xc0 xc];
disp(s);
end;
plot(xc0,T0)
xlabel('X(C)')
ylabel('T0 [K]')